@@ -540,8 +540,7 @@ def create_information_message_box(
     message_box = QDialog()
     message_box.setObjectName("message_box")
     message_box.setWindowFlags(Qt.WindowType.FramelessWindowHint)
-    message_box.setMinimumWidth(240)
-    message_box.setMaximumWidth(480)
+    message_box.setFixedWidth(360)
     style_sheet = f"""
         QDialog#message_box {{
             background-color: {background_color};
@@ -570,6 +569,8 @@ def create_information_message_box(
         border_radius = label_border_radius
     )
     main_layout.addWidget(text_label)
+    text_label.setAlignment(Qt.AlignmentFlag.AlignCenter)
+    text_label.setWordWrap(True)
     accept_button = create_button(
         text = button_text,
         font_family = button_font_family,
@@ -648,8 +649,7 @@ def create_confirmation_message_box(
     confirm_message_box = QDialog()
     confirm_message_box.setObjectName("confirm_message_box")
     confirm_message_box.setWindowFlags(Qt.WindowType.FramelessWindowHint)
-    confirm_message_box.setMinimumWidth(240)
-    confirm_message_box.setMaximumWidth(480)
+    confirm_message_box.setFixedWidth(360)
     style_sheet = f"""
         QDialog#confirm_message_box {{
             background-color: {background_color};
@@ -662,8 +662,6 @@ def create_confirmation_message_box(
     confirm_message_box.setLayout(main_layout)
     main_layout.setContentsMargins(left_margin, top_margin, right_margin, bottom_margin)
     main_layout.setSpacing(main_spacing)
-    text_layout = QHBoxLayout()
-    main_layout.addLayout(text_layout)
     text_label = create_label(
         text = text,
         font_family = label_font_family,
@@ -679,7 +677,9 @@ def create_confirmation_message_box(
         border_color = label_border_color,
         border_radius = label_border_radius
     )
-    text_layout.addWidget(text_label)
+    main_layout.addWidget(text_label)
+    text_label.setAlignment(Qt.AlignmentFlag.AlignCenter)
+    text_label.setWordWrap(True)
     buttons_layout = QHBoxLayout()
     main_layout.addLayout(buttons_layout)
     buttons_layout.setSpacing(button_spacing)
